==> gatling-http-3.0.3-sources.jar: io/gatling/http/request/builder/ws/WsRequestExpressionBuilder.scala <==
/*
 * Copyright 2011-2019 GatlingCorp (https://gatling.io)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.gatling.http.request.builder.ws

import io.gatling.commons.validation.Validation
import io.gatling.core.config.GatlingConfiguration
import io.gatling.core.session.Session
import io.gatling.http.cache.HttpCaches
import io.gatling.http.client.{ RequestBuilder => ClientRequestBuilder }
import io.gatling.http.protocol.HttpProtocol
import io.gatling.http.request.builder.{ CommonAttributes, RequestExpressionBuilder }
import io.gatling.http.util.HttpHelper

class WsRequestExpressionBuilder(
    commonAttributes: CommonAttributes,
    httpCaches:       HttpCaches,
    httpProtocol:     HttpProtocol,
    configuration:    GatlingConfiguration,
    subprotocol:      Option[String]
)
  extends RequestExpressionBuilder(commonAttributes, httpCaches, httpProtocol, configuration) {

  override protected def baseUrl: Session => Option[String] = httpCaches.wsBaseUrl

  override protected def protocolBaseUrls: List[String] =
    httpProtocol.wsPart.wsBaseUrls

  override protected def isAbsoluteUrl(url: String): Boolean =
    HttpHelper.isAbsoluteWsUrl(url)

  override protected def configureRequestBuilder(session: Session, requestBuilder: ClientRequestBuilder): Validation[ClientRequestBuilder] =
    // pass sbuprotocol
    super.configureRequestBuilder(session, requestBuilder.setWsSubprotocol(subprotocol.orNull))
}

==> gatling-http-3.3.0-sources.jar: io/gatling/http/request/builder/ws/WsRequestExpressionBuilder.scala <==
/*
 * Copyright 2011-2019 GatlingCorp (https://gatling.io)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.gatling.http.request.builder.ws

import io.gatling.commons.validation.Validation
import io.gatling.core.config.GatlingConfiguration
import io.gatling.core.session.Session
import io.gatling.http.cache.HttpCaches
import io.gatling.http.client.{ RequestBuilder => ClientRequestBuilder }
import io.gatling.http.protocol.HttpProtocol
import io.gatling.http.request.builder.{ CommonAttributes, RequestExpressionBuilder }
import io.gatling.http.util.HttpHelper

class WsRequestExpressionBuilder(
    commonAttributes: CommonAttributes,
    httpCaches: HttpCaches,
    httpProtocol: HttpProtocol,
    configuration: GatlingConfiguration,
    subprotocol: Option[String]
) extends RequestExpressionBuilder(commonAttributes, httpCaches, httpProtocol, configuration) {

  override protected def baseUrl: Session => Option[String] = httpCaches.wsBaseUrl

  override protected def protocolBaseUrls: List[String] =
    httpProtocol.wsPart.wsBaseUrls

  override protected def isAbsoluteUrl(url: String): Boolean =
    HttpHelper.isAbsoluteWsUrl(url)

  override protected def configureRequestBuilder(session: Session, requestBuilder: ClientRequestBuilder): Validation[ClientRequestBuilder] =
    // pass sbuprotocol
    super.configureRequestBuilder(session, requestBuilder.setWsSubprotocol(subprotocol.orNull))
}
